[![Git](https://git-scm.com/images/logo@2x.png)](https://git-scm.com/) --everything-is-local
![](https://git-scm.com/images/dark-mode.svg)
  * [About](https://git-scm.com/about)
    * [Trademark](https://git-scm.com/about/trademark)
  * [Learn](https://git-scm.com/learn)
    * [Book](https://git-scm.com/book)
    * [Cheat Sheet](https://git-scm.com/cheat-sheet)
    * [Videos](https://git-scm.com/videos)
    * [External Links](https://git-scm.com/doc/ext)
  * [Tools](https://git-scm.com/tools)
    * [Command Line](https://git-scm.com/tools/command-line)
    * [GUIs](https://git-scm.com/tools/guis)
    * [Hosting](https://git-scm.com/tools/hosting)
  * [Reference](https://git-scm.com/docs)
  * [Install](https://git-scm.com/install/linux)
  * [Community](https://git-scm.com/community)


  * Table of Contents
    * [NAME](https://git-scm.com/docs/scalar#_name)
    * [SYNOPSIS](https://git-scm.com/docs/scalar#_synopsis)
    * [DESCRIPTION](https://git-scm.com/docs/scalar#_description)
    * [COMMANDS](https://git-scm.com/docs/scalar#_commands)
    * [RECOMMENDED CONFIG VALUES](https://git-scm.com/docs/scalar#_recommended_config_values)
    * [SEE ALSO](https://git-scm.com/docs/scalar#_see_also)
    * [GIT](https://git-scm.com/docs/scalar#_git)


[ English ▾](https://git-scm.com/docs/scalar)
Localized versions of **scalar** manual
  1. [English ](https://git-scm.com/docs/scalar)

Want to read in your language or fix typos?
[You can help translate this page](https://github.com/jnavila/git-manpages-l10n).
[Topics ▾](https://git-scm.com/docs/scalar)
### Setup and Config
  * [ git ](https://git-scm.com/docs/git)
  * [ config ](https://git-scm.com/docs/git-config)
  * [ help ](https://git-scm.com/docs/git-help)
  * [ bugreport ](https://git-scm.com/docs/git-bugreport)
  * [ Credential helpers ](https://git-scm.com/doc/credential-helpers)


### Getting and Creating Projects
  * [ init ](https://git-scm.com/docs/git-init)
  * [ clone ](https://git-scm.com/docs/git-clone)


### Basic Snapshotting
  * [ add ](https://git-scm.com/docs/git-add)
  * [ status ](https://git-scm.com/docs/git-status)
  * [ diff ](https://git-scm.com/docs/git-diff)
  * [ commit ](https://git-scm.com/docs/git-commit)
  * [ notes ](https://git-scm.com/docs/git-notes)
  * [ restore ](https://git-scm.com/docs/git-restore)
  * [ reset ](https://git-scm.com/docs/git-reset)
  * [ rm ](https://git-scm.com/docs/git-rm)
  * [ mv ](https://git-scm.com/docs/git-mv)


### Branching and Merging
  * [ branch ](https://git-scm.com/docs/git-branch)
  * [ checkout ](https://git-scm.com/docs/git-checkout)
  * [ switch ](https://git-scm.com/docs/git-switch)
  * [ merge ](https://git-scm.com/docs/git-merge)
  * [ mergetool ](https://git-scm.com/docs/git-mergetool)
  * [ log ](https://git-scm.com/docs/git-log)
  * [ stash ](https://git-scm.com/docs/git-stash)
  * [ tag ](https://git-scm.com/docs/git-tag)
  * [ worktree ](https://git-scm.com/docs/git-worktree)


### Sharing and Updating Projects
  * [ fetch ](https://git-scm.com/docs/git-fetch)
  * [ pull ](https://git-scm.com/docs/git-pull)
  * [ push ](https://git-scm.com/docs/git-push)
  * [ remote ](https://git-scm.com/docs/git-remote)
  * [ submodule ](https://git-scm.com/docs/git-submodule)


### Inspection and Comparison
  * [ show ](https://git-scm.com/docs/git-show)
  * [ log ](https://git-scm.com/docs/git-log)
  * [ diff ](https://git-scm.com/docs/git-diff)
  * [ difftool ](https://git-scm.com/docs/git-difftool)
  * [ range-diff ](https://git-scm.com/docs/git-range-diff)
  * [ shortlog ](https://git-scm.com/docs/git-shortlog)
  * [ describe ](https://git-scm.com/docs/git-describe)


### Patching
  * [ apply ](https://git-scm.com/docs/git-apply)
  * [ cherry-pick ](https://git-scm.com/docs/git-cherry-pick)
  * [ diff ](https://git-scm.com/docs/git-diff)
  * [ rebase ](https://git-scm.com/docs/git-rebase)
  * [ revert ](https://git-scm.com/docs/git-revert)


### Debugging
  * [ bisect ](https://git-scm.com/docs/git-bisect)
  * [ blame ](https://git-scm.com/docs/git-blame)
  * [ grep ](https://git-scm.com/docs/git-grep)


### Email
  * [ am ](https://git-scm.com/docs/git-am)
  * [ apply ](https://git-scm.com/docs/git-apply)
  * [ imap-send ](https://git-scm.com/docs/git-imap-send)
  * [ format-patch ](https://git-scm.com/docs/git-format-patch)
  * [ send-email ](https://git-scm.com/docs/git-send-email)
  * [ request-pull ](https://git-scm.com/docs/git-request-pull)


### External Systems
  * [ svn ](https://git-scm.com/docs/git-svn)
  * [ fast-import ](https://git-scm.com/docs/git-fast-import)


### Server Admin
  * [ daemon ](https://git-scm.com/docs/git-daemon)
  * [ update-server-info ](https://git-scm.com/docs/git-update-server-info)


### Guides
  * [ gitattributes ](https://git-scm.com/docs/gitattributes)
  * [ Command-line interface conventions ](https://git-scm.com/docs/gitcli)
  * [ Everyday Git ](https://git-scm.com/docs/giteveryday)
  * [ Frequently Asked Questions (FAQ) ](https://git-scm.com/docs/gitfaq)
  * [ Glossary ](https://git-scm.com/docs/gitglossary)
  * [ Hooks ](https://git-scm.com/docs/githooks)
  * [ gitignore ](https://git-scm.com/docs/gitignore)
  * [ gitmodules ](https://git-scm.com/docs/gitmodules)
  * [ Revisions ](https://git-scm.com/docs/gitrevisions)
  * [ Submodules ](https://git-scm.com/docs/gitsubmodules)
  * [ Tutorial ](https://git-scm.com/docs/gittutorial)
  * [ Workflows ](https://git-scm.com/docs/gitworkflows)
  * [ All guides... ](https://git-scm.com/docs/git#_guides)


### Administration
  * [ clean ](https://git-scm.com/docs/git-clean)
  * [ gc ](https://git-scm.com/docs/git-gc)
  * [ fsck ](https://git-scm.com/docs/git-fsck)
  * [ reflog ](https://git-scm.com/docs/git-reflog)
  * [ filter-branch ](https://git-scm.com/docs/git-filter-branch)
  * [ instaweb ](https://git-scm.com/docs/git-instaweb)
  * [ archive ](https://git-scm.com/docs/git-archive)
  * [ bundle ](https://git-scm.com/docs/git-bundle)


### Plumbing Commands
  * [ cat-file ](https://git-scm.com/docs/git-cat-file)
  * [ check-ignore ](https://git-scm.com/docs/git-check-ignore)
  * [ checkout-index ](https://git-scm.com/docs/git-checkout-index)
  * [ commit-tree ](https://git-scm.com/docs/git-commit-tree)
  * [ count-objects ](https://git-scm.com/docs/git-count-objects)
  * [ diff-index ](https://git-scm.com/docs/git-diff-index)
  * [ for-each-ref ](https://git-scm.com/docs/git-for-each-ref)
  * [ hash-object ](https://git-scm.com/docs/git-hash-object)
  * [ ls-files ](https://git-scm.com/docs/git-ls-files)
  * [ ls-tree ](https://git-scm.com/docs/git-ls-tree)
  * [ merge-base ](https://git-scm.com/docs/git-merge-base)
  * [ read-tree ](https://git-scm.com/docs/git-read-tree)
  * [ rev-list ](https://git-scm.com/docs/git-rev-list)
  * [ rev-parse ](https://git-scm.com/docs/git-rev-parse)
  * [ show-ref ](https://git-scm.com/docs/git-show-ref)
  * [ symbolic-ref ](https://git-scm.com/docs/git-symbolic-ref)
  * [ update-index ](https://git-scm.com/docs/git-update-index)
  * [ update-ref ](https://git-scm.com/docs/git-update-ref)
  * [ verify-pack ](https://git-scm.com/docs/git-verify-pack)
  * [ write-tree ](https://git-scm.com/docs/git-write-tree)


[ Latest version ▾ ](https://git-scm.com/docs/scalar) scalar last updated in 2.53.0
Changes in the **scalar** manual
  1. [2.53.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2026-02-02_ ](https://git-scm.com/docs/scalar/2.53.0)
  2. [2.52.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-11-17_ ](https://git-scm.com/docs/scalar/2.52.0)
  3. 2.50.1 → 2.51.2 no changes
  4. [2.50.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-06-16_ ](https://git-scm.com/docs/scalar/2.50.0)
  5. 2.47.1 → 2.49.1 no changes
  6. [2.47.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-10-06_ ](https://git-scm.com/docs/scalar/2.47.0)
  7. 2.42.2 → 2.46.4 no changes
  8. [2.42.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-11-02_ ](https://git-scm.com/docs/scalar/2.42.1)
  9. 2.38.1 → 2.42.0 no changes
  10. [2.38.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-10-02_ ](https://git-scm.com/docs/scalar/2.38.0)


Check your version of git by running
`git --version`
##  [](https://git-scm.com/docs/scalar#_name)NAME
scalar - A tool for managing large Git repositories
##  [](https://git-scm.com/docs/scalar#_synopsis)SYNOPSIS
```
scalar clone [--single-branch] [--branch <main-branch>] [--full-clone]
	[--[no-]src] [--[no-]tags] [--[no-]maintenance] <url> [<enlistment>]
scalar list
scalar register [--[no-]maintenance] [<enlistment>]
scalar unregister [<enlistment>]
scalar run ( all | config | commit-graph | fetch | loose-objects | pack-files ) [<enlistment>]
scalar reconfigure [--maintenance=(enable|disable|keep)] [ --all | <enlistment> ]
scalar diagnose [<enlistment>]
scalar delete <enlistment>
```

##  [](https://git-scm.com/docs/scalar#_description)DESCRIPTION
Scalar is a repository management tool that optimizes Git for use in large repositories. Scalar improves performance by configuring advanced Git settings, maintaining repositories in the background, and helping to reduce data sent across the network.
An important Scalar concept is the enlistment: this is the top-level directory of the project. It usually contains the subdirectory `src/` which is a Git worktree. This encourages the separation between tracked files (inside `src/`) and untracked files, such as build artifacts (outside `src/`). When registering an existing Git worktree with Scalar whose name is not `src`, the enlistment will be identical to the worktree.
The `scalar` command implements various subcommands, and different options depending on the subcommand. With the exception of `clone`, `list` and `reconfigure` `--all`, all subcommands expect to be run in an enlistment.
The following options can be specified _before_ the subcommand:

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt--Cdirectory)-C <directory>

Before running the subcommand, change the working directory. This option imitates the same option of [git[1]](https://git-scm.com/docs/git).

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt--ckeyvalue)-c <key>=<value>

For the duration of running the specified subcommand, configure this setting. This option imitates the same option of [git[1]](https://git-scm.com/docs/git).
##  [](https://git-scm.com/docs/scalar#_commands)COMMANDS
###  [](https://git-scm.com/docs/scalar#_clone)Clone

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-cloneoptionsurlenlistment)clone [<options>] <url> [<enlistment>]

Clones the specified repository, similar to [git-clone[1]](https://git-scm.com/docs/git-clone). By default, only commit and tree objects are cloned. Once finished, the worktree is located at _< enlistment>_`/src`.
The sparse-checkout feature is enabled (except when run with `--full-clone`) and the only files present are those in the top-level directory. Use `git` `sparse-checkout` `set` to expand the set of directories you want to see, or `git` `sparse-checkout` `disable` to expand to all files (see [git-sparse-checkout[1]](https://git-scm.com/docs/git-sparse-checkout) for more details). You can explore the subdirectories outside your sparse-checkout by using `git` `ls-tree` `HEAD`[`:`_< directory>_].

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt--bname)-b <name>


[](https://git-scm.com/docs/scalar#Documentation/scalar.txt---branchname)--branch <name>

Instead of checking out the branch pointed to by the cloned repository’s HEAD, check out the _< name>_ branch instead.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt---single-branch)--single-branch


[](https://git-scm.com/docs/scalar#Documentation/scalar.txt---no-single-branch)--no-single-branch

Clone only the history leading to the tip of a single branch, either specified by the `--branch` option or the primary branch remote’s `HEAD` points at.
Further fetches into the resulting repository will only update the remote-tracking branch for the branch this option was used for the initial cloning. If the HEAD at the remote did not point at any branch when `--single-branch` clone was made, no remote-tracking branch is created.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt---src)--src


[](https://git-scm.com/docs/scalar#Documentation/scalar.txt---no-src)--no-src

By default, `scalar` `clone` places the cloned repository within a _< entlistment>_`/src` directory. Use `--no-src` to place the cloned repository directly in the _< enlistment>_ directory.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt---tags)--tags


[](https://git-scm.com/docs/scalar#Documentation/scalar.txt---no-tags)--no-tags

By default, `scalar` `clone` will fetch the tag objects advertised by the remote and future `git` `fetch` commands will do the same. Use `--no-tags` to avoid fetching tags in `scalar` `clone` and to configure the repository to avoid fetching tags in the future. To fetch tags after cloning with `--no-tags`, run `git` `fetch` `--tags`.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt---full-clone)--full-clone


[](https://git-scm.com/docs/scalar#Documentation/scalar.txt---no-full-clone)--no-full-clone

A sparse-checkout is initialized by default. This behavior can be turned off via `--full-clone`.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt---maintenance)--maintenance


[](https://git-scm.com/docs/scalar#Documentation/scalar.txt---no-maintenance)--no-maintenance

By default, `scalar` `clone` configures the enlistment to use Git’s background maintenance feature. Use the `--no-maintenance` to skip this configuration.
###  [](https://git-scm.com/docs/scalar#_list)List

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-list)list

List enlistments that are currently registered by Scalar. This subcommand does not need to be run inside an enlistment.
###  [](https://git-scm.com/docs/scalar#_register)Register

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-registerenlistment)register [<enlistment>]

Adds the enlistment’s repository to the list of registered repositories and starts background maintenance. If _< enlistment>_ is not provided, then the enlistment associated with the current working directory is registered.
Note: when this subcommand is called in a worktree that is called `src/`, its parent directory is considered to be the Scalar enlistment. If the worktree is _not_ called `src/`, it itself will be considered to be the Scalar enlistment.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt---maintenance-1)--maintenance


[](https://git-scm.com/docs/scalar#Documentation/scalar.txt---no-maintenance-1)--no-maintenance

By default, `scalar` `register` configures the enlistment to use Git’s background maintenance feature. Use the `--no-maintenance` to skip this configuration. This does not disable any maintenance that may already be enabled in other ways.
###  [](https://git-scm.com/docs/scalar#_unregister)Unregister

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-unregisterenlistment)unregister [<enlistment>]

Remove the specified repository from the list of repositories registered with Scalar and stop the scheduled background maintenance.
###  [](https://git-scm.com/docs/scalar#_run)Run

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-scalarrunallconfigcommit-graphfetchloose-objectspack-filesenlistment)scalar run ( all | config | commit-graph | fetch | loose-objects | pack-files ) [<enlistment>]

Run the given maintenance task (or all tasks, if `all` was specified). Except for `all` and `config`, this subcommand simply hands off to [git-maintenance[1]](https://git-scm.com/docs/git-maintenance) (mapping `fetch` to `prefetch` and `pack-files` to `incremental-repack`).
These tasks are run automatically as part of the scheduled maintenance, as soon as the repository is registered with Scalar. It should therefore not be necessary to run this subcommand manually.
The `config` task is specific to Scalar and configures all those opinionated default settings that make Git work more efficiently with large repositories. As this task is run as part of `scalar` `clone` automatically, explicit invocations of this task are rarely needed.
###  [](https://git-scm.com/docs/scalar#_reconfigure)Reconfigure
After a Scalar upgrade, or when the configuration of a Scalar enlistment was somehow corrupted or changed by mistake, this subcommand allows to reconfigure the enlistment.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt---all)--all

When `--all` is specified, reconfigure all enlistments currently registered with Scalar by the `scalar.repo` config key. Use this option after each upgrade to get the latest features.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt---maintenanceenabledisablekeep)--maintenance=(enable|disable|keep)

By default, Scalar configures the enlistment to use Git’s background maintenance feature; this is the same as using the `enable` value for this option. Use the `disable` value to remove each considered enlistment from background maintenance. Use ‘keep’ to leave the background maintenance configuration untouched for these repositories.
###  [](https://git-scm.com/docs/scalar#_diagnose)Diagnose

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-diagnoseenlistment)diagnose [<enlistment>]

When reporting issues with Scalar, it is often helpful to provide the information gathered by this command, including logs and certain statistics describing the data shape of the current enlistment.
The output of this command is a `.zip` file that is written into a directory adjacent to the worktree in the `src` directory.
###  [](https://git-scm.com/docs/scalar#_delete)Delete

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-deleteenlistment)delete <enlistment>

This subcommand lets you delete an existing Scalar enlistment from your local file system, unregistering the repository.
##  [](https://git-scm.com/docs/scalar#_recommended_config_values)RECOMMENDED CONFIG VALUES
As part of both `scalar` `clone` and `scalar` `register`, certain Git config values are set to optimize for large repositories or cross-platform support. These options are updated in new Git versions according to the best known advice for large repositories, and users can get the latest recommendations by running `scalar` `reconfigure` [`--all`].
This section lists justifications for the config values that are set in the latest version.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-amkeepCRtrue)am.keepCR=true

This setting is important for cross-platform development across Windows and non-Windows platforms and keeping carriage return (_\r_) characters in certain workflows.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-commitGraphchangedPathstrue)commitGraph.changedPaths=true

This setting helps the background maintenance steps that compute the serialized commit-graph to also store changed-path Bloom filters. This accelerates file history commands and allows users to automatically benefit without running a foreground command.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-commitGraphgenerationVersion1)commitGraph.generationVersion=1

While the preferred version is 2 for performance reasons, existing users that had version 1 by default will need special care in upgrading to version 2. This is likely to change in the future as the upgrade story solidifies.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-coreautoCRLFfalse)core.autoCRLF=false

This removes the transformation of worktree files to add CRLF line endings when only LF line endings exist. This is removed for performance reasons. Repositories that use tools that care about CRLF line endings should commit the necessary files with those line endings instead.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-corelogAllRefUpdatestrue)core.logAllRefUpdates=true

This enables the reflog on all branches. While this is a performance cost for large repositories, it is frequently an important data source for users to get out of bad situations or to seek support from experts.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-coresafeCRLFfalse)core.safeCRLF=false

Similar to `core.autoCRLF=false`, this disables checks around whether the CRLF conversion is reversible. This is a performance improvement, but can be dangerous if `core.autoCRLF` is reenabled by the user.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-credentialhttpsdevazurecomuseHttpPathtrue)credential.https://dev.azure.com.useHttpPath=true

This setting enables the `credential.useHttpPath` feature only for web URLs for Azure DevOps. This is important for users interacting with that service using multiple organizations and thus multiple credential tokens.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-featureexperimentalfalse)feature.experimental=false

This disables the "experimental" optimizations grouped under this feature config. The expectation is that all valuable optimizations are also set explicitly by Scalar config, and any differences are intentional. Notable differences include several bitmap-related config options which are disabled for client-focused Scalar repos.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-featuremanyFilesfalse)feature.manyFiles=false

This disables the "many files" optimizations grouped under this feature config. The expectation is that all valuable optimizations are also set explicitly by Scalar config, and any differences are intentional.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-fetchshowForcedUpdatesfalse)fetch.showForcedUpdates=false

This disables the check at the end of `git` `fetch` that notifies the user if the ref update was a forced update (one where the previous position is not reachable from the latest position). This check can be very expensive in large repositories, so is disabled and replaced with an advice message. Set `advice.fetchShowForcedUpdates=false` to disable this advice message.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-fetchunpackLimit1)fetch.unpackLimit=1

This setting prevents Git from unpacking packfiles into loose objects as they are downloaded from the server. The default limit of 100 was intended as a way to prevent performance issues from too many packfiles, but Scalar uses background maintenance to group packfiles and cover them with a multi-pack-index, removing this issue.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-fetchwriteCommitGraphfalse)fetch.writeCommitGraph=false

This config setting was created to help users automatically update their commit-graph files as they perform fetches. However, this takes time from foreground fetches and pulls and Scalar uses background maintenance for this function instead.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-gcauto0)gc.auto=0

This disables automatic garbage collection, since Scalar uses background maintenance to keep the repository data in good shape.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-guiGCWarningfalse)gui.GCWarning=false

Since Scalar disables garbage collection by setting `gc.auto=0`, the `git-gui` tool may start to warn about this setting. Disable this warning as Scalar’s background maintenance configuration makes the warning irrelevant.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-indexskipHashtrue)index.skipHash=true

Disable computing the hash of the index contents as it is being written. This assists with performance, especially for large index files.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-indexthreadstrue)index.threads=true

This tells Git to automatically detect how many threads it should use when reading the index due to the default value of `core.preloadIndex`, which enables parallel index reads. This explicit setting also enables `index.recordOffsetTable=true` to speed up parallel index reads.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-indexversion4)index.version=4

This index version adds compression to the path names, reducing the size of the index in a significant way for large repos. This is an important performance boost.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-logexcludeDecorationrefsprefetch)log.excludeDecoration=refs/prefetch/*

Since Scalar enables background maintenance with the `incremental` strategy, this setting avoids polluting `git` `log` output with refs stored by the background prefetch operations.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-mergerenamestrue)merge.renames=true

When computing merges in large repos, it is particularly important to detect renames to maximize the potential for a result that will validate correctly. Users performing merges locally are more likely to be doing so because a server-side merge (via pull request or similar) resulted in conflicts. While this is the default setting, it is set specifically to override a potential change to `diff.renames` which a user may set for performance reasons.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-mergestatfalse)merge.stat=false

This disables a diff output after computing a merge. This improves performance of `git` `merge` for large repos while reducing noisy output.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-packuseBitmapsfalse)pack.useBitmaps=false

This disables the use of `.bitmap` files attached to packfiles. Bitmap files are optimized for server-side use, not client-side use. Scalar disables this to avoid some performance issues that can occur if a user accidentally creates `.bitmap` files.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-packusePathWalktrue)pack.usePathWalk=true

This enables the `--path-walk` option to `git` `pack-objects` by default. This can accelerate the computation and compression of packfiles created by `git` `push` and other repack operations.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-receiveautoGCfalse)receive.autoGC=false

Similar to `gc.auto`, this setting is disabled in preference of background maintenance.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-statusaheadBehindfalse)status.aheadBehind=false

This disables the ahead/behind calculation that would normally happen during a `git` `status` command. This information is frequently ignored by users but can be expensive to calculate in large repos that receive thousands of commits per day. The calculation is replaced with an advice message that can be disabled by disabling the `advice.statusAheadBehind` config.
The following settings are different based on which platform is in use:

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-coreuntrackedCachetruefalse)core.untrackedCache=(true|false)

The untracked cache feature is important for performance benefits on large repositories, but has demonstrated some bugs on Windows filesystems. Thus, this is set for other platforms but disabled on Windows.

[](https://git-scm.com/docs/scalar#Documentation/scalar.txt-httpsslBackendschannel)http.sslBackend=schannel

On Windows, the `openssl` backend has some issues with certain types of remote providers and certificate types. Override the default setting to avoid these common problems.
##  [](https://git-scm.com/docs/scalar#_see_also)SEE ALSO
[git-clone[1]](https://git-scm.com/docs/git-clone), [git-maintenance[1]](https://git-scm.com/docs/git-maintenance).
##  [](https://git-scm.com/docs/scalar#_git)GIT
Part of the [git[1]](https://git-scm.com/docs/git) suite
### scalar
[About this site](https://git-scm.com/site)
Patches, suggestions, and comments are welcome.
Git is a member of [Software Freedom Conservancy](https://git-scm.com/sfc)
